#!/bin/sh
##############################################################
# glucopy.sh
#
# Creates the /glucopy directory
# Copies partition information in sys_partitions.txt
# Optionally makes a copy of the MBR in mbr.bin
# Copies working GNU/Linux system to .tgz files
#
# USAGE:
# Boot system with a rescue CD or any bootable CD
# that supports your type of disks (SATA/SCSI or IDE).
# run the back-up script: ./glucopy.sh
# 
# In this example the system is on /dev/sda
# /dev/sda1 is a small partition with HW manufacturer utilities
# /dev/sda2 has system root (/) -> mounted to /mnt
# /dev/sda3 is a spare (blank) partition
# /dev/sda4 has home (/home) and space to hold
#           the information to be copied -> mounted to /mnt2
#
# 061116 jp/dm
##############################################################
# Change the following to reflect the place where your system root (/) 
# and the home directories (/home/*) are mounted
mkdir /tmp/mnt1
mkdir /tmp/mnt2
mount /dev/sda2 /tmp/mnt1
mount /dev/sda4 /tmp/mnt2

# The directory to hold the system copy is placed on the larger partition
mkdir /tmp/mnt2/glucopy

# Change to the working directory
cd /tmp/mnt2/glucopy

# Optionally copy MBR information
#dd if=/dev/sda of=mbr.bin bs=512 count=1

# Copy partition information
/sbin/sfdisk -d /dev/sda > sys_partitions.txt

# Make tarballs, preserving file permissions (default if run as root)
tar -C /tmp/mnt1 -cpvzf syscopy.tgz boot bin etc lib media opt root sbin usr var dev 

# Move up a level
cd ..
# here we are under the /home directory level
# notice that --exclude will exclude anything that matches a _pattern_
# the glucopy directory will still be created in the tarball
tar -cpvzf ./glucopy/homecopy.tgz * --exclude=glucopy/*

# Copy the backup/restore scripts (here under root /), and the sfdisk program,  as well
cp /glucopy.sh ./glucopy
cp /glurestore.sh ./glucopy
cp /sbin/sfdisk ./glucopy

# Notify user
echo -e “glucopy: finished \a”
